Submitted By: Ken Moffat <ken at linuxfromscratch dot org>
Date: 2018-02-18
Initial Package Version: 6.9.6-3
Upstream Status: N/A
Origin: Self
Description: Allows the libraries of ImageMagick-6 to be installed
without the programs or man-pages, and with versioned pkgconfig files
so that ImageMagick-7 can be installed alongside this.  Do not build
perl here if doing this (the version from ImageMagick-7 will use the
libraries from 7), and edit any cmake programs using this (e.g.
inkscape-0.92) so that they look for the -6 pkgconfig files.

Rediffed for 6.9.9-34.

Internally, ImageMagick-7 is a major change, and the names of the
libraries and the include directories differ.

For packages which use a conventional configure script, pass
IMAGEMAGICK_CFLAGS=-I/usr/include/ImageMagick-6 and
IMAGEMAGICK_LIBS="-lMagickCore-6.Q16HDRI -lMagick++-6.Q16HDRI -lMagickWand-6.Q16HDRI"

In some places I have had to hardcode -6 because I could not persuade
the build system to convert @MAGICK_CORE_VERSION@ in one file or for
the names of the files.

Also, my raw patch deletes wand/Wand.pc.in but gnu patch fails there,
believing it is a reversal (not understood, a git patch would be
easier if we all had git, mentioned because it will probably happen
again if this has to be rediffed for future versions).

diff -Naur a/configure b/configure
--- a/configure	2018-01-22 15:23:30.000000000 +0000
+++ b/configure	2018-02-18 06:29:41.137422347 +0000
@@ -36931,7 +36931,7 @@
 # ==============================================================================
 # Generate build environment
 # ==============================================================================
-ac_config_files="$ac_config_files common.shi config/configure.xml config/delegates.xml config/ImageMagick.rdf config/MagickCore.dox config/MagickWand.dox config/Magick++.dox config/type-apple.xml config/type-dejavu.xml config/type-ghostscript.xml config/type-urw-base35.xml config/type-windows.xml config/type.xml ImageMagick.spec Magick++/bin/Magick++-config magick/ImageMagick.pc Magick++/lib/ImageMagick++.pc Magick++/lib/Magick++.pc magick/Magick-config magick/MagickCore-config magick/MagickCore.pc magick/version.h Makefile magick.sh PerlMagick/check.sh PerlMagick/default/Magick.pm PerlMagick/Makefile.PL PerlMagick/default/Makefile.PL PerlMagick/quantum/Makefile.PL PerlMagick/quantum/quantum.pm PerlMagick/quantum/quantum.xs PerlMagick/quantum/typemap utilities/animate.1 utilities/compare.1 utilities/composite.1 utilities/conjure.1 utilities/convert.1 utilities/display.1 utilities/identify.1 utilities/ImageMagick.1 utilities/import.1 utilities/mogrify.1 utilities/montage.1 utilities/stream.1 wand/MagickWand-config wand/MagickWand.pc wand/Wand-config wand/Wand.pc"
+ac_config_files="$ac_config_files common.shi config/configure.xml config/delegates.xml config/ImageMagick.rdf config/MagickCore.dox config/MagickWand.dox config/Magick++.dox config/type-apple.xml config/type-dejavu.xml config/type-ghostscript.xml config/type-urw-base35.xml config/type-windows.xml config/type.xml ImageMagick.spec Magick++/bin/Magick++-config magick/ImageMagick-6.pc Magick++/lib/ImageMagick++-6.pc Magick++/lib/Magick++-6.pc magick/Magick-config magick/MagickCore-config magick/MagickCore-6.pc magick/version.h Makefile magick.sh PerlMagick/check.sh PerlMagick/default/Magick.pm PerlMagick/Makefile.PL PerlMagick/default/Makefile.PL PerlMagick/quantum/Makefile.PL PerlMagick/quantum/quantum.pm PerlMagick/quantum/quantum.xs PerlMagick/quantum/typemap utilities/animate.1 utilities/compare.1 utilities/composite.1 utilities/conjure.1 utilities/convert.1 utilities/display.1 utilities/identify.1 utilities/ImageMagick.1 utilities/import.1 utilities/mogrify.1 utilities/montage.1 utilities/stream.1 wand/MagickWand-config wand/MagickWand-6.pc wand/Wand-config wand/Wand-6.pc"
 
 cat >confcache <<\_ACEOF
 # This file is a shell script that caches the results of configure
diff -Naur a/configure.ac b/configure.ac
--- a/configure.ac	2018-01-22 15:19:44.000000000 +0000
+++ b/configure.ac	2018-02-18 06:18:30.383015502 +0000
@@ -3964,12 +3964,12 @@
     config/type.xml \
     ImageMagick.spec \
     Magick++/bin/Magick++-config \
-    magick/ImageMagick.pc \
-    Magick++/lib/ImageMagick++.pc \
-    Magick++/lib/Magick++.pc \
+    magick/ImageMagick-6.pc \
+    Magick++/lib/ImageMagick++-6.pc \
+    Magick++/lib/Magick++-6.pc \
     magick/Magick-config \
     magick/MagickCore-config \
-    magick/MagickCore.pc \
+    magick/MagickCore-6.pc \
     magick/version.h \
     Makefile \
     magick.sh \
@@ -3994,9 +3994,9 @@
     utilities/montage.1 \
     utilities/stream.1 \
     wand/MagickWand-config \
-    wand/MagickWand.pc \
+    wand/MagickWand-6.pc \
     wand/Wand-config \
-    wand/Wand.pc ])
+    wand/Wand-6.pc ])
 AC_OUTPUT
 
 # ==============================================================================
diff -Naur a/magick/ImageMagick-6.pc.in b/magick/ImageMagick-6.pc.in
--- a/magick/ImageMagick-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/magick/ImageMagick-6.pc.in	2018-02-18 06:18:30.383015502 +0000
@@ -0,0 +1,14 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=MagickCore-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+ 
+Name: ImageMagick-@MAGICK_MAJOR_VERSION@
+Description: ImageMagick - convert, edit, and compose images (ABI @MAGICK_ABI_SUFFIX@)
+URL: https://www.imagemagick.org
+Version: @PACKAGE_VERSION@
+Cflags:  -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
+Libs: -L${libdir} -l${libname}
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/magick/ImageMagick.pc.in b/magick/ImageMagick.pc.in
--- a/magick/ImageMagick.pc.in	2018-01-22 15:19:44.000000000 +0000
+++ b/magick/ImageMagick.pc.in	1970-01-01 01:00:00.000000000 +0100
@@ -1,14 +0,0 @@
-prefix=@prefix@
-exec_prefix=@exec_prefix@
-libdir=@libdir@
-includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
-includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
-libname=MagickCore-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
- 
-Name: ImageMagick
-Description: ImageMagick - convert, edit, and compose images (ABI @MAGICK_ABI_SUFFIX@)
-URL: https://www.imagemagick.org
-Version: @PACKAGE_VERSION@
-Cflags:  -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
-Libs: -L${libdir} -l${libname}
-Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/magick/MagickCore-6.pc.in b/magick/MagickCore-6.pc.in
--- a/magick/MagickCore-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/magick/MagickCore-6.pc.in	2018-02-18 06:18:30.383015502 +0000
@@ -0,0 +1,15 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=MagickCore-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+moduledir=@libdir@/ImageMagick-@MAGICK_MAJOR_VERSION@.@MAGICK_MINOR_VERSION@.@MAGICK_MICRO_VERSION@/modules-@MAGICK_ABI_SUFFIX@
+
+Name: MagickCore-@MAGICK_MAJOR_VERSION@
+Description: MagickCore - C API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
+URL: https://www.imagemagick.org
+Version: @PACKAGE_VERSION@
+Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
+Libs: -L${libdir} -l${libname}
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/magick/MagickCore.pc.in b/magick/MagickCore.pc.in
--- a/magick/MagickCore.pc.in	2018-01-22 15:19:44.000000000 +0000
+++ b/magick/MagickCore.pc.in	1970-01-01 01:00:00.000000000 +0100
@@ -1,15 +0,0 @@
-prefix=@prefix@
-exec_prefix=@exec_prefix@
-libdir=@libdir@
-includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
-includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
-libname=MagickCore-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
-moduledir=@libdir@/ImageMagick-@MAGICK_MAJOR_VERSION@.@MAGICK_MINOR_VERSION@.@MAGICK_MICRO_VERSION@/modules-@MAGICK_ABI_SUFFIX@
-
-Name: MagickCore
-Description: MagickCore - C API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
-URL: https://www.imagemagick.org
-Version: @PACKAGE_VERSION@
-Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
-Libs: -L${libdir} -l${libname}
-Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/Magick++/lib/ImageMagick++-6.pc.in b/Magick++/lib/ImageMagick++-6.pc.in
--- a/Magick++/lib/ImageMagick++-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/Magick++/lib/ImageMagick++-6.pc.in	2018-02-18 06:18:30.383015502 +0000
@@ -0,0 +1,14 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=Magick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+ 
+Name: ImageMagick++-@MAGICK_MAJOR_VERSION@
+Description: Magick++ - C++ API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
+Version: @PACKAGE_VERSION@
+Requires: MagickWand-@MAGICK_MAJOR_VERSION@
+Libs: -L${libdir} -l${libname}
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
+Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
diff -Naur a/Magick++/lib/ImageMagick++.pc.in b/Magick++/lib/ImageMagick++.pc.in
--- a/Magick++/lib/ImageMagick++.pc.in	2018-01-22 15:19:43.000000000 +0000
+++ b/Magick++/lib/ImageMagick++.pc.in	1970-01-01 01:00:00.000000000 +0100
@@ -1,14 +0,0 @@
-prefix=@prefix@
-exec_prefix=@exec_prefix@
-libdir=@libdir@
-includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
-includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
-libname=Magick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
- 
-Name: ImageMagick++
-Description: Magick++ - C++ API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
-Version: @PACKAGE_VERSION@
-Requires: MagickWand
-Libs: -L${libdir} -l${libname}
-Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
-Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
diff -Naur a/Magick++/lib/Magick++-6.pc.in b/Magick++/lib/Magick++-6.pc.in
--- a/Magick++/lib/Magick++-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/Magick++/lib/Magick++-6.pc.in	2018-02-18 06:18:30.383015502 +0000
@@ -0,0 +1,14 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=Magick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+ 
+Name: Magick++-@MAGICK_MAJOR_VERSION@
+Description: Magick++ - C++ API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
+Version: @PACKAGE_VERSION@
+Requires: MagickWand-@MAGICK_MAJOR_VERSION@
+Libs: -L${libdir} -l${libname}
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
+Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
diff -Naur a/Magick++/lib/Magick++.pc.in b/Magick++/lib/Magick++.pc.in
--- a/Magick++/lib/Magick++.pc.in	2018-01-22 15:19:43.000000000 +0000
+++ b/Magick++/lib/Magick++.pc.in	1970-01-01 01:00:00.000000000 +0100
@@ -1,14 +0,0 @@
-prefix=@prefix@
-exec_prefix=@exec_prefix@
-libdir=@libdir@
-includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
-includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
-libname=Magick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
- 
-Name: Magick++
-Description: Magick++ - C++ API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
-Version: @PACKAGE_VERSION@
-Requires: MagickWand
-Libs: -L${libdir} -l${libname}
-Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
-Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
diff -Naur a/Makefile.in b/Makefile.in
--- a/Makefile.in	2018-01-22 15:20:04.000000000 +0000
+++ b/Makefile.in	2018-02-18 06:20:52.101400618 +0000
@@ -303,9 +303,9 @@
 	config/type-dejavu.xml config/type-ghostscript.xml \
 	config/type-urw-base35.xml config/type-windows.xml \
 	config/type.xml ImageMagick.spec Magick++/bin/Magick++-config \
-	magick/ImageMagick.pc Magick++/lib/ImageMagick++.pc \
-	Magick++/lib/Magick++.pc magick/Magick-config \
-	magick/MagickCore-config magick/MagickCore.pc magick/version.h \
+	magick/ImageMagick-6.pc Magick++/lib/ImageMagick++-6.pc \
+	Magick++/lib/Magick++-6.pc magick/Magick-config \
+	magick/MagickCore-config magick/MagickCore-6.pc magick/version.h \
 	magick.sh PerlMagick/check.sh PerlMagick/default/Magick.pm \
 	PerlMagick/Makefile.PL PerlMagick/default/Makefile.PL \
 	PerlMagick/quantum/Makefile.PL PerlMagick/quantum/quantum.pm \
@@ -314,8 +314,8 @@
 	utilities/conjure.1 utilities/convert.1 utilities/display.1 \
 	utilities/identify.1 utilities/ImageMagick.1 \
 	utilities/import.1 utilities/mogrify.1 utilities/montage.1 \
-	utilities/stream.1 wand/MagickWand-config wand/MagickWand.pc \
-	wand/Wand-config wand/Wand.pc
+	utilities/stream.1 wand/MagickWand-config wand/MagickWand-6.pc \
+	wand/Wand-config wand/Wand-6.pc
 CONFIG_CLEAN_VPATH_FILES =
 am__vpath_adj_setup = srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`;
 am__vpath_adj = case $$p in \
@@ -2494,8 +2494,8 @@
 	$(srcdir)/tests/Makefile.am $(srcdir)/utilities/Makefile.am \
 	$(srcdir)/wand/Makefile.am \
 	$(top_srcdir)/Magick++/bin/Magick++-config.in \
-	$(top_srcdir)/Magick++/lib/ImageMagick++.pc.in \
-	$(top_srcdir)/Magick++/lib/Magick++.pc.in \
+	$(top_srcdir)/Magick++/lib/ImageMagick++-6.pc.in \
+	$(top_srcdir)/Magick++/lib/Magick++-6.pc.in \
 	$(top_srcdir)/PerlMagick/Makefile.PL.in \
 	$(top_srcdir)/PerlMagick/check.sh.in \
 	$(top_srcdir)/PerlMagick/default/Magick.pm.in \
@@ -2525,10 +2525,10 @@
 	$(top_srcdir)/config/type-urw-base35.xml.in \
 	$(top_srcdir)/config/type-windows.xml.in \
 	$(top_srcdir)/config/type.xml.in \
-	$(top_srcdir)/magick/ImageMagick.pc.in \
+	$(top_srcdir)/magick/ImageMagick-6.pc.in \
 	$(top_srcdir)/magick/Magick-config.in \
 	$(top_srcdir)/magick/MagickCore-config.in \
-	$(top_srcdir)/magick/MagickCore.pc.in \
+	$(top_srcdir)/magick/MagickCore-6.pc.in \
 	$(top_srcdir)/magick/version.h.in \
 	$(top_srcdir)/utilities/ImageMagick.1.in \
 	$(top_srcdir)/utilities/animate.1.in \
@@ -2543,9 +2543,9 @@
 	$(top_srcdir)/utilities/montage.1.in \
 	$(top_srcdir)/utilities/stream.1.in \
 	$(top_srcdir)/wand/MagickWand-config.in \
-	$(top_srcdir)/wand/MagickWand.pc.in \
+	$(top_srcdir)/wand/MagickWand-6.pc.in \
 	$(top_srcdir)/wand/Wand-config.in \
-	$(top_srcdir)/wand/Wand.pc.in ChangeLog config/ar-lib \
+	$(top_srcdir)/wand/Wand.pc-6.in ChangeLog config/ar-lib \
 	config/compile config/config.guess config/config.sub \
 	config/depcomp config/install-sh config/ltmain.sh \
 	config/missing config/mkinstalldirs
@@ -4236,8 +4236,8 @@
   magick/MagickCore-config
 
 MAGICK_PKGCONFIG = \
-  magick/ImageMagick.pc \
-  magick/MagickCore.pc \
+  magick/ImageMagick-6.pc \
+  magick/MagickCore-6.pc \
   magick/ImageMagick-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc \
   magick/MagickCore-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc
 
@@ -4658,9 +4658,9 @@
 	magick/Magick-config.in \
 	magick/MagickCore-config.in \
 	$(MAGICK_MANS) \
-	magick/ImageMagick.pc.in \
+	magick/ImageMagick-6.pc.in \
 	magick/libMagickCore.map \
-	magick/MagickCore.pc.in \
+	magick/MagickCore-6.pc.in \
 	magick/config.h_vms \
 	magick/mac.c \
 	magick/nt-base.c \
@@ -4775,8 +4775,8 @@
 	wand/MagickWand-config
 
 WAND_PKGCONFIG = \
-	wand/MagickWand.pc \
-	wand/Wand.pc \
+	wand/MagickWand-6.pc \
+	wand/Wand-6.pc \
 	wand/MagickWand-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc \
 	wand/Wand-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc
 
@@ -4800,9 +4800,9 @@
 	wand/ChangeLog \
 	wand/libMagickWand.map \
 	wand/MagickWand-config.1 \
-	wand/MagickWand.pc.in \
+	wand/MagickWand-6.pc.in \
 	wand/Wand-config.1 \
-	wand/Wand.pc.in
+	wand/Wand-6.pc.in
 
 WAND_CLEANFILES = 
 MAGICKPP_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/Magick++/lib
@@ -4831,8 +4831,8 @@
 	Magick++/bin/Magick++-config.1
 
 MAGICKPP_PKGCONFIG_OPT = \
-	Magick++/lib/Magick++.pc \
-	Magick++/lib/ImageMagick++.pc \
+	Magick++/lib/Magick++-6.pc \
+	Magick++/lib/ImageMagick++-6.pc \
 	Magick++/lib/Magick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc \
 	Magick++/lib/ImageMagick++-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc
 
@@ -4849,9 +4849,9 @@
 	Magick++/README \
 	Magick++/bin/Magick++-config.1 \
 	Magick++/bin/Magick++-config.in \
-	Magick++/lib/ImageMagick++.pc.in \
+	Magick++/lib/ImageMagick++-6.pc.in \
 	Magick++/lib/libMagick++.map \
-	Magick++/lib/Magick++.pc.in \
+	Magick++/lib/Magick++-6.pc.in \
 	Magick++/demo/model.miff \
 	Magick++/demo/smile.miff \
 	Magick++/demo/smile_anim.miff \
@@ -5341,17 +5341,17 @@
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 Magick++/bin/Magick++-config: $(top_builddir)/config.status $(top_srcdir)/Magick++/bin/Magick++-config.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-magick/ImageMagick.pc: $(top_builddir)/config.status $(top_srcdir)/magick/ImageMagick.pc.in
+magick/ImageMagick-6.pc: $(top_builddir)/config.status $(top_srcdir)/magick/ImageMagick-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-Magick++/lib/ImageMagick++.pc: $(top_builddir)/config.status $(top_srcdir)/Magick++/lib/ImageMagick++.pc.in
+Magick++/lib/ImageMagick++-6.pc: $(top_builddir)/config.status $(top_srcdir)/Magick++/lib/ImageMagick++-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-Magick++/lib/Magick++.pc: $(top_builddir)/config.status $(top_srcdir)/Magick++/lib/Magick++.pc.in
+Magick++/lib/Magick++-6.pc: $(top_builddir)/config.status $(top_srcdir)/Magick++/lib/Magick++-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 magick/Magick-config: $(top_builddir)/config.status $(top_srcdir)/magick/Magick-config.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 magick/MagickCore-config: $(top_builddir)/config.status $(top_srcdir)/magick/MagickCore-config.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-magick/MagickCore.pc: $(top_builddir)/config.status $(top_srcdir)/magick/MagickCore.pc.in
+magick/MagickCore-6.pc: $(top_builddir)/config.status $(top_srcdir)/magick/MagickCore-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 magick/version.h: $(top_builddir)/config.status $(top_srcdir)/magick/version.h.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
@@ -5399,11 +5399,11 @@
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 wand/MagickWand-config: $(top_builddir)/config.status $(top_srcdir)/wand/MagickWand-config.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-wand/MagickWand.pc: $(top_builddir)/config.status $(top_srcdir)/wand/MagickWand.pc.in
+wand/MagickWand-6.pc: $(top_builddir)/config.status $(top_srcdir)/wand/MagickWand-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 wand/Wand-config: $(top_builddir)/config.status $(top_srcdir)/wand/Wand-config.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
-wand/Wand.pc: $(top_builddir)/config.status $(top_srcdir)/wand/Wand.pc.in
+wand/Wand-6.pc: $(top_builddir)/config.status $(top_srcdir)/wand/Wand-6.pc.in
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 
 install-codersLTLIBRARIES: $(coders_LTLIBRARIES)
@@ -11470,7 +11470,7 @@
 	install-data-local install-docDATA install-filtersLTLIBRARIES \
 	install-includeHEADERS install-magickincHEADERS \
 	install-magickincarchHEADERS install-magickppincHEADERS \
-	install-magickpptopincHEADERS install-man \
+	install-magickpptopincHEADERS \
 	install-pkgconfigDATA install-wandincHEADERS
 
 install-dvi: install-dvi-am
@@ -11488,6 +11488,8 @@
 
 install-info-am:
 
+install-libs-only: install-libLTLIBRARIES install-data-am
+
 install-man: install-man1
 
 install-pdf: install-pdf-am
@@ -11664,7 +11666,7 @@
 @WITH_PERL_FALSE@distclean-perl:
 
 # create a copy for pc file (ideally the non abi should be symlinked)
-%-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc: %.pc
+%-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@.pc: %-@MAGICK_MAJOR_VERSION@.pc
 	cp -f $^ $@
 
 all-local: $(MAGICKPP_LOCAL_TARGETS) $(PERLMAGICK_ALL_LOCAL_TARGETS) $(MAINTAINER_TARGETS)
diff -Naur a/wand/MagickWand-6.pc.in b/wand/MagickWand-6.pc.in
--- a/wand/MagickWand-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/wand/MagickWand-6.pc.in	2018-02-18 06:18:30.385018956 +0000
@@ -0,0 +1,15 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=MagickWand-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+ 
+Name: MagickWand-@MAGICK_MAJOR_VERSION@
+Description: MagickWand - C API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
+URL: https://www.imagemagick.org
+Version: @PACKAGE_VERSION@
+Requires: MagickCore-@MAGICK_MAJOR_VERSION@
+Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
+Libs: -L${libdir} -l${libname} 
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/wand/MagickWand.pc.in b/wand/MagickWand.pc.in
--- a/wand/MagickWand.pc.in	2018-01-22 15:19:44.000000000 +0000
+++ b/wand/MagickWand.pc.in	1970-01-01 01:00:00.000000000 +0100
@@ -1,15 +0,0 @@
-prefix=@prefix@
-exec_prefix=@exec_prefix@
-libdir=@libdir@
-includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
-includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
-libname=MagickWand-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
- 
-Name: MagickWand
-Description: MagickWand - C API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
-URL: https://www.imagemagick.org
-Version: @PACKAGE_VERSION@
-Requires: MagickCore
-Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
-Libs: -L${libdir} -l${libname} 
-Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
diff -Naur a/wand/Wand-6.pc.in b/wand/Wand-6.pc.in
--- a/wand/Wand-6.pc.in	1970-01-01 01:00:00.000000000 +0100
+++ b/wand/Wand-6.pc.in	2018-02-18 06:18:30.385018956 +0000
@@ -0,0 +1,15 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@/ImageMagick-@MAGICK_MAJOR_VERSION@
+includearchdir=@INCLUDEARCH_DIR@/ImageMagick-@MAGICK_MAJOR_VERSION@
+libname=MagickWand-@MAGICK_MAJOR_VERSION@.@MAGICK_ABI_SUFFIX@
+ 
+Name: MagickWand-6
+Description: MagickCore - C API for ImageMagick (ABI @MAGICK_ABI_SUFFIX@)
+URL: https://www.imagemagick.org
+Version: @PACKAGE_VERSION@
+Requires: MagickCore-6
+Cflags: -I${includearchdir} -I${includedir} @MAGICK_PCFLAGS@
+Libs: -L${libdir} -l${libname}
+Libs.private: -L${libdir} -l${libname} @MAGICK_LIBS@ @MATH_LIBS@
